import React from "react";
import { UserOutlined } from "@ant-design/icons";
import { Button } from "antd";

export interface StaffCardProps {
	staff: {
		id?: string;
		showname?: string;
		username?: string;
		meta?: {
			photoUrl?: string;
			rank?: string;
		};
		replyCount?: number;
		receiveCount?: number;
	};
}

export function StaffCard({ staff }: StaffCardProps) {
	const handleSendLetter = () => {
		window.open(`/editor?&receiverId=${staff.id}`, "_blank");
	};
	return (
		<div className="shadow-elegant border  border-white rounded-lg overflow-hidden flex transition-transform duration-300 hover:translate-y-[-5px] hover:shadow-lg">
			{/* Image Container */}
			<div className="w-24 h-32 flex-shrink-0 flex items-center justify-center relative">
				{staff.meta?.photoUrl ? (
					<img
						src={staff.meta.photoUrl}
						alt={staff?.showname || staff?.username}
						className="w-full h-full object-cover"
					/>
				) : (
					<div className="flex flex-col items-center justify-center text-gray-400 w-full h-full bg-gray-200">
						<UserOutlined style={{ fontSize: "32px" }} />
					</div>
				)}
			</div>

			{/* Content Container */}
			<div className="flex-1 p-4 flex flex-col justify-center gap-2">
				<h3 className="text-2xl font-semibold text-primary">
					{staff?.showname || staff?.username || "未知"}
				</h3>
				<div className=" flex justify-start gap-2 items-center text-base text-primary">
					<div className="">
						答复 {staff?.replyCount} / 收信 {staff?.receiveCount}
					</div>
					<Button
						size="small"
						onClick={handleSendLetter}
						type="primary"
						style={{
							boxShadow: "none",
						}}>
						我要写信
					</Button>
				</div>
			</div>
		</div>
	);
}
