import { NavLink, useLocation } from "react-router-dom";
import { useNavItem } from "./useNavItem";
import { twMerge } from "tailwind-merge";
import React from "react";

interface NavItem {
	to: string;
	label: string;
	icon?: React.ReactNode;
}

interface NavigationProps {
	className?: string;
}

export default function Navigation({ className }: NavigationProps) {
	const { navItems } = useNavItem();
	const location = useLocation();

	const isActive = (to: string) => {
		const [pathname, search] = to.split("?");
		return (
			location.pathname === pathname &&
			(!search ? !location.search : location.search === `?${search}`)
		);
	};

	return (
		<nav className={twMerge("mt-4 w-full", className)}>
			<div className="flex justify-between">
				<div className="flex w-full space-x-4 overflow-x-auto scrollbar-none">
					{navItems.map((item) => (
						<NavLink
							key={item.to}
							to={item.to}
							className={({ isActive: active }) =>
								twMerge(
									"flex-1 px-6 py-4 text-2xl font-bold rounded-xl", // 调整字体大小和粗细
									"transition-all duration-200 ease-out",
									"bg-gradient-to-r from-primary-500/80 to-primary-400 text-white",
									"hover:from-primary-500 hover:to-primary-500 ",
									active &&
										"from-primary-600 to-primary-500    *:"
								)
							}>
							<span className="flex items-center justify-center gap-4">
								{" "}
								{/* 增加图标和文字间距 */}
								{item.icon &&
									React.cloneElement(
										item.icon as React.ReactElement,
										{ style: { fontSize: "38px" } }
									)}{" "}
								{/* 调整图标大小 */}
								<span className="tracking-wide">
									{item.label}
								</span>
							</span>
						</NavLink>
					))}
				</div>
			</div>
		</nav>
	);
}
