import { api } from "@nice/client";
import { TaxonomySlug } from "@nice/common";
import React, { useMemo } from "react";
import {
	FileSearchOutlined,
	FormOutlined,
	InboxOutlined,
	MailOutlined,
	SendOutlined,
} from "@ant-design/icons";
import {
	FileTextOutlined,
	ScheduleOutlined,
	QuestionCircleOutlined,
	FolderOutlined,
	TagsOutlined,
} from "@ant-design/icons";
import { useAuth } from "@web/src/providers/auth-provider";
import { env } from "@web/src/env";

export interface NavItem {
	to: string;
	label: string;
	icon?: React.ReactNode;
}

export function useNavItem() {
	const { user } = useAuth();
	const { data } = api.term.findMany.useQuery({
		where: {
			taxonomy: { slug: TaxonomySlug.CATEGORY },
		},
	});

	const navItems = useMemo(() => {
		// 定义固定的导航项
		const staticItems = {
			letterList: {
				to: "/",
				label: "全部来信",
				icon: <MailOutlined className="text-base" />,
			},
			editor: {
				to: "/editor",
				label: "我要写信",
				icon: <FormOutlined className="text-base" />,
			},
			letterProgress: {
				to: "/letter-progress",
				label: "信件查询",
				icon: <FileSearchOutlined className="text-base" />,
			},
			inbox: {
				to: user ? "/inbox" : "auth",
				label: "我的信件",
				icon: <InboxOutlined className="text-base" />,
			},
			help: {
				to: env.LIB_URL || "27.57.72.38",
				label: "法规查询",
				icon: <QuestionCircleOutlined className="text-base" />,
			},
		};

		// 按照指定顺序返回导航项
		return [
			staticItems.letterList,
			staticItems.editor,
			staticItems.letterProgress,
			staticItems.inbox,
			staticItems.help,
		].filter(Boolean);
	}, [data, user]);

	return { navItems };
}
