import { useContext, useEffect, useState } from "react";
import { PostDetailContext } from "../context/PostDetailContext";
import PostCommentEditor from "../PostCommentEditor";
import PostCommentList from "../PostCommentList";
import { useVisitor } from "@nice/client";
import { VisitType } from "@nice/common";
import Header from "../PostHeader/Header";
import Content from "../PostHeader/Content";
import { Button, Input, Skeleton } from "antd";

export default function PostDetailLayout() {
	const { post, user, canSee, setKeyCode, isLoading } =
		useContext(PostDetailContext);
	const { read } = useVisitor();

	useEffect(() => {
		if (post) {
			read.mutateAsync({
				data: {
					visitorId: user?.id || null,
					postId: post.id,
					type: VisitType.READED,
				},
			});
		}
	}, [post]);
	const [password, setPassword] = useState("");
	const handlePasswordSubmit = () => {
		setKeyCode(password);
	};
	if (isLoading) {
		return (
			<div style={{ padding: "20px" }}>
				<Skeleton active avatar paragraph={{ rows: 4 }} />
			</div>
		);
	}
	if (!canSee) {
		return (
			<div
				className=" justify-center gap-2"
				style={{
					height: 400,
				}}>
				<div className=" mb-2  mt-8 flex gap-1 justify-center text-primary text-2xl font-bold flex-1">
					该信件受到密码保护！
				</div>
				<div className="flex gap-1 justify-center items-center flex-1 ">
					<Input
						placeholder="请输入密码"
						onChange={(e) => setPassword(e.target.value)}
						style={{
							width: 400,
						}}
					/>
					<Button type="primary" onClick={handlePasswordSubmit}>
						确认
					</Button>
				</div>
			</div>
		);
	}
	return (
		<>
			<Header></Header>
			<Content></Content>
			<PostCommentEditor></PostCommentEditor>
			<PostCommentList></PostCommentList>
		</>
	);
}
